/*
 * Programming in Java, Jacobs University, 2015
 *
 * Print all @Note annotations of the Test class.
 */

import java.lang.reflect.AnnotatedElement;

public class Main
{

    public static void printNote(AnnotatedElement elem)
    {
	if (elem == null || !elem.isAnnotationPresent(Note.class)) {
	    return;
	}
	Note annotation = elem.getAnnotation(Note.class);
	String annotationValue = annotation.value();
	Priority annotationPriority = annotation.priority();
	System.out.println("  [" + annotationPriority + "] " + elem.toString() + ": " + annotationValue);
    }
    
    public static void printNotes(AnnotatedElement[] elems)
    {
	for (AnnotatedElement elem: elems) {
	    printNote(elem);
	}
    }

    public static void printAnnotationsForClass(Class classObj)
    {
	System.out.println("Package Notes:");
	printNote(classObj.getPackage());
	
	System.out.println("\nClass Notes:");
	printNote(classObj);
	
	System.out.println("\nField Notes:");
	printNotes(classObj.getDeclaredFields());
	
	System.out.println("\nConstructor Notes:");
	printNotes(classObj.getDeclaredConstructors());
	
	System.out.println("\nMethod Notes:");
	printNotes(classObj.getDeclaredMethods());
    }

    public static void main(String[] args)
    {
	printAnnotationsForClass(Test.class);
    }
    
}
